@@ -5,7 +5,6 @@ import re
 import sys
 import time
 import traceback
-import logging
 
 import numpy as np
 import tensorflow as tf
@@ -23,17 +22,31 @@ from treform.utility.watch_util import WatchUtil
 from treform.utility.log_util import LogUtil
 
 
-from treform.spelling.config import KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR, \
-    KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE, KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE, KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE, KO_WIKIPEDIA_ORG_CHARACTERS_FILE, \
-    KO_WIKIPEDIA_ORG_DIR
+from treform.spelling.config import Config
 
-log = LogUtil.get_logger(source_filepath=None, level=logging.INFO, console_mode=True)
-
-tf.compat.v1.disable_eager_execution()
 
 class SpellingErrorCorrection(object):
     graph = {}
 
+    @classmethod
+    def initialize(cls, json_file):
+        config = Config(json_file)
+        global log
+        global KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR
+        global KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_CHARACTERS_FILE
+        global KO_WIKIPEDIA_ORG_DIR
+
+        log = config.log
+        KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR = config.KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR
+        KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_CHARACTERS_FILE = config.KO_WIKIPEDIA_ORG_CHARACTERS_FILE
+        KO_WIKIPEDIA_ORG_DIR = config.KO_WIKIPEDIA_ORG_DIR
+
     @classmethod
     def learning(cls, total_epoch, n_train, n_valid, n_test, batch_size, window_size, noise_rate, noise_sampling, model_file, features_vector, labels_vector,
                  n_hidden1,
@@ -73,7 +86,7 @@ class SpellingErrorCorrection(object):
                 log.info('noise_rate: %s' % noise_rate)
 
                 features, labels = [], []
-                with gzip.open(data_file, 'rt', encoding='utf-8') as f:
+                with gzip.open(data_file, 'rt') as f:
                     for i, line in enumerate(f, 1):
                         if total < i:
                             break
@@ -92,6 +105,20 @@ class SpellingErrorCorrection(object):
                                 labels.append(chars)
                                 log.debug('create dataset... %s "%s" -> "%s"' % (name, noised_chars, chars))
 
+                # log.info('noise_sampling: %s' % noise_sampling)
+                #         for nth_sample in range(noise_sampling): # 초성, 중성, 종성 단위로 노이즈 생성
+                #             for start in range(0, len(sentence) - window_size + 1):
+                #                 chars = sentence[start: start + window_size]
+                #                 noised_chars = SpellingErrorCorrection.encode_noise(chars, noise_rate=noise_rate, noise_with_blank=True)
+                #                 if chars == noised_chars:
+                #                     continue
+                #                 if i % check_interval == 0 and nth_sample == 0:
+                #                     log.info('create dataset... %s "%s" -> "%s"' % (name, noised_chars, chars))
+                #                 features.append(noised_chars)
+                #                 labels.append(chars)
+
+                # print('dataset features:', features)
+                # print('dataset labels:', labels)
                 dataset = DataSet(features=features, labels=labels, features_vector=features_vector, labels_vector=labels_vector, name=name)
                 log.info('dataset save... %s' % dataset_file)
                 dataset.save(dataset_file, gzip_format=True, verbose=True)
@@ -122,8 +149,9 @@ class SpellingErrorCorrection(object):
 
         X, Y, dropout_keep_prob, train_step, cost, y_hat, accuracy = SpellingErrorCorrection.build_DAE(n_features, window_size, noise_rate, n_hidden1,
                                                                                                        learning_rate, watch)
-        with tf.compat.v1.Session() as sess:
-            sess.run(tf.compat.v1.global_variables_initializer())
+
+        with tf.Session() as sess:
+            sess.run(tf.global_variables_initializer())
             check_interval = max(1, min(1000, n_train // 10))
 
             nth_train, nth_input, total_input = 0, 0, total_epoch * train.size
@@ -158,7 +186,7 @@ class SpellingErrorCorrection(object):
             model_dir = os.path.dirname(model_file)
             if not os.path.exists(model_dir):
                 os.makedirs(model_dir)
-            saver = tf.compat.v1.train.Saver()
+            saver = tf.train.Saver()
             saver.save(sess, model_file)
             watch.stop('model save...')
             log.info('model save OK. %s' % model_file)
@@ -186,29 +214,45 @@ class SpellingErrorCorrection(object):
             log.info('noise_rate: %.1f' % noise_rate)
             log.info('n_hidden1: %s' % n_hidden1)
 
-            tf.compat.v1.set_random_seed(777)  # for reproducibility
+            tf.set_random_seed(777)  # for reproducibility
 
-            X = tf.compat.v1.placeholder(tf.compat.v1.float32, [None, n_features], name='X')  # shape=(batch_size, window_size * feature_vector.size)
-            Y = tf.compat.v1.placeholder(tf.compat.v1.float32, [None, n_features], name='Y')  # shape=(batch_size, window_size * feature_vector.size)
-            dropout_keep_prob = tf.compat.v1.placeholder(tf.compat.v1.float32)
+            X = tf.placeholder(tf.float32, [None, n_features], name='X')  # shape=(batch_size, window_size * feature_vector.size)
+            Y = tf.placeholder(tf.float32, [None, n_features], name='Y')  # shape=(batch_size, window_size * feature_vector.size)
+            dropout_keep_prob = tf.placeholder(tf.float32)
+
+            # layers = 3
+            # n_hidden2 = n_hidden1
+            # W1 = tf.Variable(tf.random_normal([n_features, n_hidden1]), name='W1')
+            # b1 = tf.Variable(tf.random_normal([n_hidden1]), name='b1')
+            # layer1 = tf.nn.sigmoid(tf.matmul(X, W1) + b1, name='layer1')
+            # layer1_dropout = tf.nn.dropout(layer1, dropout_keep_prob, name='layer1_dropout')
+            #
+            # W2 = tf.Variable(tf.random_normal([n_hidden1, n_hidden2]), name='W2')
+            # b2 = tf.Variable(tf.random_normal([n_hidden2]), name='b2')
+            # layer2 = tf.nn.sigmoid(tf.matmul(layer1_dropout, W2) + b2, name='layer2')
+            # layer2_dropout = tf.nn.dropout(layer2, dropout_keep_prob, name='layer2_dropout')
+            #
+            # W3 = tf.Variable(tf.random_normal([n_hidden1, n_features]), name='W3')
+            # b3 = tf.Variable(tf.random_normal([n_features]), name='b3')
+            # y_hat = tf.add(tf.matmul(layer2_dropout, W3), b3, name='y_hat')
 
             # layers = 2
-            W1 = tf.compat.v1.Variable(tf.compat.v1.random_normal([n_features, n_hidden1]), name='W1')
-            b1 = tf.compat.v1.Variable(tf.compat.v1.random_normal([n_hidden1]), name='b1')
-            layer1 = tf.compat.v1.nn.sigmoid(tf.compat.v1.matmul(X, W1) + b1, name='layer1')
+            W1 = tf.Variable(tf.random_normal([n_features, n_hidden1]), name='W1')
+            b1 = tf.Variable(tf.random_normal([n_hidden1]), name='b1')
+            layer1 = tf.nn.sigmoid(tf.matmul(X, W1) + b1, name='layer1')
             layer1_dropout = tf.nn.dropout(layer1, dropout_keep_prob, name='layer1_dropout')
 
-            W2 = tf.compat.v1.Variable(tf.compat.v1.random_normal([n_hidden1, n_features]), name='W2')
-            b2 = tf.compat.v1.Variable(tf.compat.v1.random_normal([n_features]), name='b2')
-            y_hat = tf.compat.v1.add(tf.compat.v1.matmul(layer1_dropout, W2), b2, name='y_hat')  # shape=(batch_size, window_size * feature_vector.size)
+            W2 = tf.Variable(tf.random_normal([n_hidden1, n_features]), name='W2')
+            b2 = tf.Variable(tf.random_normal([n_features]), name='b2')
+            y_hat = tf.add(tf.matmul(layer1_dropout, W2), b2, name='y_hat')  # shape=(batch_size, window_size * feature_vector.size)
 
-            labels_hat = tf.compat.v1.reshape(y_hat, shape=(-1, window_size, features_vector_size))  # shape=(batch_size, window_size, feature_vector.size)
-            labels = tf.compat.v1.reshape(Y, shape=(-1, window_size, features_vector_size))  # shape=(batch_size, window_size, feature_vector.size)
+            labels_hat = tf.reshape(y_hat, shape=(-1, window_size, features_vector_size))  # shape=(batch_size, window_size, feature_vector.size)
+            labels = tf.reshape(Y, shape=(-1, window_size, features_vector_size))  # shape=(batch_size, window_size, feature_vector.size)
 
-            cost = tf.compat.v1.reduce_mean(tf.compat.v1.nn.softmax_cross_entropy_with_logits(logits=labels_hat, labels=labels), name='cost')
-            train_step = tf.compat.v1.train.AdamOptimizer(learning_rate=learning_rate).minimize(cost)
+            cost = tf.reduce_mean(tf.nn.softmax_cross_entropy_with_logits(logits=labels_hat, labels=labels), name='cost')
+            train_step = tf.train.AdamOptimizer(learning_rate=learning_rate).minimize(cost)
 
-            accuracy = tf.compat.v1.reduce_mean(tf.compat.v1.cast(tf.compat.v1.abs(tf.compat.v1.nn.softmax(y_hat) - Y) < 0.1, dtype=tf.compat.v1.float32), name='accuracy')
+            accuracy = tf.reduce_mean(tf.cast(tf.abs(tf.nn.softmax(y_hat) - Y) < 0.1, dtype=tf.float32), name='accuracy')
             # log.debug('X:', X)
             # log.debug('Y:', Y)
             # log.debug('y_hat:', y_hat)
@@ -302,6 +346,10 @@ class SpellingErrorCorrection(object):
 
 
 if __name__ == '__main__':
+
+    json_file = 'D:\\python_workspace\\treform\\resources\\korean_spelling_config.json'
+    SpellingErrorCorrection.initialize(json_file)
+
     train_sentences_file = KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
     valid_sentences_file = KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
     test_sentences_file = KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
@@ -324,14 +372,11 @@ if __name__ == '__main__':
             n_train = int('1,000,000'.replace(',', ''))
 
         if is_server():  # batch server
-            n_train = 1000
+            n_train = 10000
             n_valid = min(10, n_train)
             n_test = min(10, n_train)
         else:  # for demo
-            #n_train = 10000
-            #n_valid = min(10, n_train)
-            #n_test = min(10, n_train)
-            n_train = n_valid = n_test = 500
+            n_train = n_valid = n_test = 3
 
         if noise_rate is None or window_size is None:
             window_size = 10  # 2 ~ 10 # feature로 추출할 문자 수 (label과 동일)
@@ -340,7 +385,7 @@ if __name__ == '__main__':
         dropout_keep_rate = 1.0  # 0.0 ~ 1.0 # one hot vector에 경우에 dropout 사용시, 학습이 안 됨.
         noise_sampling = 100  # 한 입력에 대하여 몇 개의 노이즈 샘플을 생성할지. blank 방식(문자 단위)으로 noise 생성할 때는 사용 안함.
 
-        total_epoch = max(5, 20 // window_size)  # 10 ~ 100 # window_size 가 클 수록 total_epoch는 작아도 됨.
+        total_epoch = max(10, 100 // window_size)  # 10 ~ 100 # window_size 가 클 수록 total_epoch는 작아도 됨.
         batch_size = min(100, 10 * window_size)  # 1 ~ 100 # one hot vector 입력이면, batch_size 작게 잡아야 학습이 잘 된다. batch_size가 너무 크면, 전혀 학습이 안 됨.
 
         n_hidden1 = min(1000, 10 * window_size)  # 10 ~ 1000
@@ -397,15 +442,9 @@ if __name__ == '__main__':
 
         # if is_my_pc() or is_my_gpu_pc() or not os.path.exists(model_file + '.index') or not os.path.exists(model_file + '.meta'):
         if not os.path.exists(model_file + '.index') or not os.path.exists(model_file + '.meta'):
-            if n_train > int('100,000'.replace(',', '')):
-                #SlackUtil.send_message('%s start (max_sentences=%s, window_size=%s, noise_rate=%.1f)' % (sys.argv[0], n_train, window_size, noise_rate))
-                print('%s start (max_sentences=%s, window_size=%s, noise_rate=%.1f)' % (sys.argv[0], n_train, window_size, noise_rate))
             SpellingErrorCorrection.learning(total_epoch, n_train, n_valid, n_test, batch_size, window_size, noise_rate, noise_sampling,
                                              model_file, features_vector, labels_vector, n_hidden1=n_hidden1,
                                              learning_rate=learning_rate, dropout_keep_rate=dropout_keep_rate)
-            if n_train > int('100,000'.replace(',', '')):
-                #SlackUtil.send_message('%s end (max_sentences=%s, window_size=%s, noise_rate=%.1f)' % (sys.argv[0], n_train, window_size, noise_rate))
-                print('%s end (max_sentences=%s, window_size=%s, noise_rate=%.1f)' % (sys.argv[0], n_train, window_size, noise_rate))
         log.info('chek result...')
         watch = WatchUtil()
         watch.start('read sentences')
@@ -417,7 +456,7 @@ if __name__ == '__main__':
         else:
             sentences_file = train_sentences_file
 
-        with gzip.open(sentences_file, 'rt', encoding='utf-8') as f:
+        with gzip.open(sentences_file, 'rt') as f:
             for i, line in enumerate(f, 1):
                 if len(sentences) >= n_test:
                     break
@@ -428,15 +467,12 @@ if __name__ == '__main__':
         watch.stop('read sentences')
 
         watch.start('run tensorflow')
-        # Add an op to initialize the variables.
-        init_op = tf.compat.v1.initialize_all_variables()
-
-        with tf.compat.v1.Session() as sess:
-            sess.run(init_op)
 
+        with tf.Session() as sess:
             X, Y, dropout_keep_prob, train_step, cost, y_hat, accuracy = SpellingErrorCorrection.build_DAE(n_features, window_size, noise_rate, n_hidden1,
                                                                                                            learning_rate, watch)
-            saver = tf.compat.v1.train.Saver()
+
+            saver = tf.train.Saver()
             try:
                 restored = saver.restore(sess, model_file)
             except Exception as e:
