@@ -23,9 +23,8 @@ from treform.utility.watch_util import WatchUtil
 from treform.utility.log_util import LogUtil
 
 
-from treform.spelling.config import KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR, \
-    KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE, KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE, KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE, KO_WIKIPEDIA_ORG_CHARACTERS_FILE, \
-    KO_WIKIPEDIA_ORG_DIR
+from treform.spelling.config import Config
+
 
 log = LogUtil.get_logger(source_filepath=None, level=logging.INFO, console_mode=True)
 
@@ -34,6 +33,25 @@ tf.compat.v1.disable_eager_execution()
 class SpellingErrorCorrection(object):
     graph = {}
 
+    @classmethod
+    def initialize(cls, json_file):
+        config = Config(json_file)
+        global log
+        global KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR
+        global KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
+        global KO_WIKIPEDIA_ORG_CHARACTERS_FILE
+        global KO_WIKIPEDIA_ORG_DIR
+
+        log = config.log
+        KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR = config.KO_WIKIPEDIA_ORG_SPELLING_ERROR_CORRECTION_MODEL_DIR
+        KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE = config.KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
+        KO_WIKIPEDIA_ORG_CHARACTERS_FILE = config.KO_WIKIPEDIA_ORG_CHARACTERS_FILE
+        KO_WIKIPEDIA_ORG_DIR = config.KO_WIKIPEDIA_ORG_DIR
+
     @classmethod
     def learning(cls, total_epoch, n_train, n_valid, n_test, batch_size, window_size, noise_rate, noise_sampling, model_file, features_vector, labels_vector,
                  n_hidden1,
@@ -302,6 +320,9 @@ class SpellingErrorCorrection(object):
 
 
 if __name__ == '__main__':
+    json_file = 'D:\\python_workspace\\treform\\resources\\korean_spelling_config.json'
+    SpellingErrorCorrection.initialize(json_file)
+
     train_sentences_file = KO_WIKIPEDIA_ORG_TRAIN_SENTENCES_FILE
     valid_sentences_file = KO_WIKIPEDIA_ORG_VALID_SENTENCES_FILE
     test_sentences_file = KO_WIKIPEDIA_ORG_TEST_SENTENCES_FILE
