@@ -1,7 +1,5 @@
 
-import os
 from numpy import *
-os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
 from sklearn.preprocessing import LabelEncoder
 from sklearn.preprocessing import OneHotEncoder
 
